/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.marshalling;


import java.io.IOException;
import java.io.InputStream;
import java.io.ObjectInputStream;

/**
 * Reader which use the context classloader when recreating the object.
 * @author Florent Benoit
 */
public class CtxClassLoaderObjectInputStream extends ClassLoaderObjectInputStream {

    /**
     * This inputstream reader needs an input stream for its constructor.
     * @param inputStream input stream containing bytes
     * @throws IOException if super class fails
     */
    public CtxClassLoaderObjectInputStream(final InputStream inputStream) throws IOException {
        super(inputStream, Thread.currentThread().getContextClassLoader());
    }

    /**
     * This inputstream reader needs an input stream for its constructor.
     * @param inputStream input stream containing bytes
     * @throws IOException if super class fails
     */
    public CtxClassLoaderObjectInputStream(final ObjectInputStream inputStream) throws IOException {
        super(inputStream, Thread.currentThread().getContextClassLoader());
    }


}
